pub trait DeployScript {
// Required method
fn deploy(
&self,
env: &HostEnv,
container: &mut DeployedContractsContainer,
) -> Result<(), DeployError>;
}Expand description
Script that deploys contracts to the blockchain and stores contract data for further use.
In a deploy script, you can define the contracts that you want to deploy to the blockchain and write metadata to the container.
Required Methods
fn deploy( &self, env: &HostEnv, container: &mut DeployedContractsContainer, ) -> Result<(), DeployError>
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".