pub struct DeployedContractsContainer { /* private fields */ }Expand description
Struct representing the deployed contracts.
This struct is used to store the contracts name and address at the deploy time and to retrieve a reference to the contract at runtime.
The data is stored in a TOML file deployed_contracts.toml in the
{project_root}/resources directory.
Implementations
Sourceimpl DeployedContractsContainer
impl DeployedContractsContainer
pub fn apply_deploy_mode(&self, mode: String) -> Result<(), ContractError>
Sourcepub fn add_contract_named<T: HostRef + HasIdent>(
&self,
contract: &T,
package_name: Option<String>,
) -> Result<(), ContractError>
pub fn add_contract_named<T: HostRef + HasIdent>( &self, contract: &T, package_name: Option<String>, ) -> Result<(), ContractError>
Adds a contract to the container.
Sourcepub fn add_contract<T: HostRef + HasIdent>(
&self,
contract: &T,
) -> Result<(), ContractError>
pub fn add_contract<T: HostRef + HasIdent>( &self, contract: &T, ) -> Result<(), ContractError>
Adds a contract to the container.
Sourcepub fn last_updated(&self) -> String
pub fn last_updated(&self) -> String
Returns the timestamp of the last write to the contracts file (RFC 3339).