pub struct OdraCli { /* private fields */ }Expand description
Command line interface for Odra smart contracts.
Implementations
Sourceimpl OdraCli
impl OdraCli
Sourcepub fn contracts_file<P: AsRef<Path>>(self, path: P) -> Self
pub fn contracts_file<P: AsRef<Path>>(self, path: P) -> Self
Sets the path to a file that stores the deployed contract addresses.
The path is relative to the resources directory in the project root.
Sourcepub fn contract<T: SchemaEntrypoints + SchemaCustomTypes + SchemaEvents + OdraContract>(
self,
) -> Self
pub fn contract<T: SchemaEntrypoints + SchemaCustomTypes + SchemaEvents + OdraContract>( self, ) -> Self
Adds a contract to the CLI.
Generates a subcommand for the contract with all of its entry points except the init entry point.
To call the constructor of the contract, implement and register the DeployScript.
Sourcepub fn named_contract<T: SchemaEntrypoints + SchemaCustomTypes + SchemaEvents + OdraContract>(
self,
name: String,
) -> Self
pub fn named_contract<T: SchemaEntrypoints + SchemaCustomTypes + SchemaEvents + OdraContract>( self, name: String, ) -> Self
Adds a named contract to the CLI, in case of multiple instances of the same contract.
Generates a subcommand for the contract with all of its entry points except the init entry point.
To call the constructor of the contract, implement and register the DeployScript.
Sourcepub fn deploy(self, script: impl DeployScript + 'static) -> Self
pub fn deploy(self, script: impl DeployScript + 'static) -> Self
Adds a deploy script to the CLI.
There is only one deploy script allowed in the CLI.
Sourcepub fn scenario<S: ScenarioMetadata + Scenario>(self, scenario: S) -> Self
pub fn scenario<S: ScenarioMetadata + Scenario>(self, scenario: S) -> Self
Adds a scenario to the CLI.
Scenarios are user-defined commands that can be run from the CLI. If there is a complex set of commands that need to be run in a specific order, a scenario can be used to group them together.